@@ -690,21 +690,23 @@ sub evlwrapper {
 
 1;
 
+
 =head1 NAME
 
-Debug::Statements provides an easy way to insert and enable/disable debug statements.
+Debug::Statements - provides an easy way to insert and enable/disable debug statements.
 
 =head1 SYNOPSIS
 
 The C<d()> function prints the name of the variable AND its value.
 
-This implementation been optimized to minimize programmer keystrokes (yours).
+This implementation been optimized to minimize your keystrokes.
 
 =head2 Example code
 
     my $myvar = 'some value';
     my @list = ('zero', 1, 'two', "3");
     my %hash = ('one' => 2, 'three' => 4);
+    
     use Debug::Statements;
     my $d = 1;
     d "Hello world";
@@ -729,29 +731,40 @@ This implementation been optimized to minimize programmer keystrokes (yours).
 
 =head1 BACKGROUND
 
-=head2 Advantages of debug statements:
+=head2 Advantages of debug statements
     
+"The most effective debugging tool is still careful thought, coupled with judiciously placed print statements"
+- Brian Kernighan, Unix for Beginners (1979)
+
 =over
 
-"The most effective debugging tool is still careful thought, coupled with judiciously placed print statements" - Brian Kernighan, "Unix for Beginners" (1979)
-
+=item *
 Familiarity - everyone has used them.
 
+=item *
 When strategically placed, they show the values of key variables as well as the flow of control.																													          
 
+=item *
 May be left in the code to facilitate debugging, when the code next needs to be enhanced.
 
+=item *
 May be turned on to help remotely debug problems.
 
-Printing the names of executing subroutines can be particularly useful when debugging large unfamiliar programs produced by multiple developers over the span of years.	
+=item *
+Printing the names of executing subroutines can be particularly useful
+when debugging large unfamiliar programs produced by multiple developers over the span of years.	
 
-Can be used in conjuction with a debugger, which can be used to change variables on-the-fly, step into libraries, or skip/repeat sections of code
+=item *
+Can be used in conjuction with a debugger, which can be used to
+change variables on-the-fly, step into libraries, or skip/repeat sections of code
 
-If the results are saved to a file, file comparisons can be useful during regression testing.
+=item *
+If the results are saved to a file, file comparisons can be useful
+during regression testing.
 
 =back
 
-=head2 Traditional debug statement example:
+=head2 Traditional debug statement example
     
     my $d = 1;
     my $myvar = 'some value';
@@ -760,25 +773,32 @@ If the results are saved to a file, file comparisons can be useful during regres
     if ($d) { print "\nDEBUG: Dumping \@list:\n"; Dumpvalue->new->dumpValue(\@list) }
     if ($d) { print "\nDEBUG: Dumping \%hash:\n"; Dumpvalue->new->dumpValue(\%hash) }
 
-=head2 Disadvantages of traditional "print" debug statements:
-    
+=head2 Disadvantages of traditional "print" debug statements
+
 =over
 
+=item *
 Tedious, require many keystrokes to type
 
+=item *
 Reduces readability of the source code.
 
+=item *
 Print statements clutter the standard output
 
+=item *
 Need to be removed or commented out later
 
+=item *
 If some statements are mistakenly left in, the output can cause problems or confusion
 
-The next time the code needs to be enhanced, any removed print statements need to be re-inserted or uncommented
+=item *
+The next time the code needs to be enhanced,
+any removed print statements need to be re-inserted or uncommented
 
 =back
 
-=head1 Debug::Statements Example:
+=head1 Debug::Statements Example
 
 C<Debug::Statements::d()> provides an easy way to insert and enable/disable debug statements.
 
@@ -787,7 +807,7 @@ C<Debug::Statements::d()> provides an easy way to insert and enable/disable debu
     my $d = 1;
     d '$myvar';
 
-=head2 Output:
+=head2 Output
     
     DEBUG sub mysub:  $myvar = 'some value'
 
@@ -795,7 +815,7 @@ This is all you need to know to get started.
 
 =head1 FEATURES
 
-=head2 Arrays, hashes and refs:
+=head2 Arrays, hashes and refs
 
     d '@list';
     d '$list[2]';
@@ -809,12 +829,12 @@ This is all you need to know to get started.
     d '$hashref->{key}';
     d '$hashref->{$key}';
 
-=head2 Plain text can be entered as a comment:
+=head2 Plain text can be entered as a comment
     
     d 'Processing...';
     d "This comment prints the value of a variable: $myvar";
 
-=head2 Multiple debug levels:
+=head2 Multiple debug levels
     
     use Debug::Statements qw(d d2 d0 D);
     
@@ -838,7 +858,7 @@ This is all you need to know to get started.
     d '\n$myvar\n\n';
     d '\n-------\n@list\n--------\n';
 
-=head2 Multiple variables can be printed easily:
+=head2 Multiple variables can be printed easily
     
     d '$myvar $myvar2 $myvar3';
     or
@@ -850,13 +870,13 @@ This is all you need to know to get started.
     
 Each of these examples prints one line each for $myvar, $myvar2, and $myvar3
 
-=head2 Alternate syntax with parentheses:
+=head2 Alternate syntax with parentheses
     
     d('$myvar');
     
 =head1 OPTIONS
 
-Options may be specifed with an 2nd argment to C<d()>:
+Options may be specifed with an 2nd argment to C<d()>
 
 =over
 
@@ -873,7 +893,8 @@ B<n>
 print line Number $. of the input file
 
 B<q>
-treat the string as text, do not try to evaluate it.  This is useful if you are parsing another Perl script, and the text contains sigil characters C<$@%>
+treat the string as text, do not try to evaluate it.
+This is useful if you are parsing another Perl script, and the text contains sigil characters C<$@%>
 
 B<r>
 tRuncate output (defaults to 10 lines)
@@ -892,7 +913,7 @@ compress array and hash dumps to save screen space
 
 =back
 
-=head2 Examples:
+=head2 Examples
 
 To print $line chomped and with line number and timestamp
 
@@ -902,33 +923,27 @@ To print %hash in a compressed format
   
    d('%hash', 'z');
 
-=head2 Negating options:
+=head2 Negating options
 
 To negate an option, capitialize it (use 'B' instead of 'b')
 
-=head2 Persistent options:
+=head2 Persistent options
     
 Options are only valid for the current debug statement
 
 To make the current options global (peristent), append a star *
 
-For example, to set timestamp globally:
+For example, to set timestamp globally
 	
    d('$var', 't*');
 	
-For example, to unset timestamp globally:
+For example, to unset timestamp globally
     
    '$var', 'T*');
 
 =head1 REQUIREMENTS
 
-B<PadWalker must be installed>
-
-=over
-
-http://search.cpan.org/~robin/PadWalker-2.0/PadWalker.pm
-
-=back
+B<L<PadWalker> must be installed>
 
 In addition, the test suites require Test::Fatal, Test::More, and Test::Output
   
@@ -936,42 +951,48 @@ In addition, the test suites require Test::Fatal, Test::More, and Test::Output
 
 B<Your code must have a variable '$d' defined to enable the debug statements>
 
-Exception:  C<D()> does not require the $d variable to exist.  It always prints.  See "Multiple debug levels" above.
+Exception:  C<D()> does not require the $d variable to exist.
+It always prints.  See "Multiple debug levels" above.
 
 $d was chosen because it is easy to type and intuitive
 
-If your code already uses '$d' for another purpose, this can be changed with C<Debug::Statements::setFlag()>
+If your code already uses '$d' for another purpose,
+this can be changed with C<Debug::Statements::setFlag()>
 
-Your code must not already contain a local subroutine called 'd()', since this function is imported
+Your code must not already contain a local subroutine called 'd()',
+since this function is imported
 
-Consider enabling $d through the command line of your script:
+Consider enabling $d through the command line of your script
     
     use Getopt::Long;
     my %opt;
     my $d = 0;
     GetOptions( \%opt, 'd' => sub{$d=1}, 'dd' => sub{$d=2}, ... );
 
-This provides an easy way for others to set your code into debug mode.  They can then capture stdout and email it to you.
+This provides an easy way for others to set your code into debug mode.
+They can then capture stdout and email it to you.
 
 =head2 Quoting
 
 Calls to d() should use 'single quotes' instead of "double quotes"
 
-Exception:  To produce custom output, call d() with double-quotes.  As is always the case with double-quotes in Perl, variables will be interpolated into values before entering the d() subroutine.
+Exception:  To produce custom output, call d() with double-quotes.
+As is always the case with double-quotes in Perl,
+variables will be interpolated into values before entering the d() subroutine.
 
-=head3 Example #1:
+=head3 Example #1
 
     d "Found pattern: $mynum in file $filename";
     
-=head3 Output #1:
+=head3 Output #1
     
     DEBUG sub mysub:  Found pattern asdf in file foo.txt
 
-=head3 Example #2:
+=head3 Example #2
 
     d "Found $key and replaced with $subtable_ref->{$key} on:  $line"
     
-=head3 Output #2:
+=head3 Output #2
     
     DEBUG sub mysub:  Found foo and replaced with bar on:  foobar
 
@@ -982,7 +1003,7 @@ This means that d() will try to print the names and values of those variables.
 	
 =head2 Functions
 
-The module includes functions which affect global operation:
+The module includes functions which affect global operation
     
    Debug::Statements::enable();             # enable operation (default)
    Debug::Statements::disable();            # disable operation, even if $d >= 1
@@ -992,16 +1013,19 @@ The module includes functions which affect global operation:
 
 =head1 LIMITATIONS
 
-Not supported:
+Not supported
 
 =over
 
+=item *
 Array slices such as C<$listvar[1:3]>
 
+=item *
 Some special variables such as C<$1 $_ @_>
 ...but any of these can be printed by using "double quotes",
-since this will cause Perl to evaluate the expression before calling d().  For example:  d "@_"
+since this will cause Perl to evaluate the expression before calling d().  For example  d "@_"
         
+=item *
 The evaluation is of variables does not support the full range of Perl syntax.
 Most cases work, for example:  C<d '$hash{$key}'>
 However hashes used as hash keys will not work, for example:  C<d '$hash{$hash2{$key}}'>
@@ -1023,23 +1047,26 @@ When $d >= 1, prints an ls -l listing of $myfilename.
 
 Note that ' ' is not used inside ls()
 
-=head1 Perl versions:
+=head1 Perl versions
+
+This module has been tested on
 
-This module has been tested on:
-    
 =over
-    
-Linux 5.8.6, 5.8.8, 5.12, 5.14, and 5.20.  It may even work on 5.006
 
+=item *
+Linux 5.8.6, 5.8.8, 5.12, 5.14, and 5.20
+
+=item *
 Windows 5.20
 
 =back
 
 =head1 GORY DETAILS
       
-=head2 How it works:
+=head2 How it works
 
-C<PadWalker::peek_my()> gets the value of $d and the contents of your variables (from outside its scope!)  The variable values are stored in an internal hash reference
+C<PadWalker::peek_my()> gets the value of $d and the contents of your variables
+(from outside its scope!)  The variable values are stored in an internal hash reference
 
 It does NOT change the values of your variables.
 
@@ -1047,20 +1074,24 @@ C<caller()[3]> gets the name of subroutine which encloses your code
 
 C<Data::Dumper> pretty-prints the contents of your variable
 
-=head2 Performance:
+=head2 Performance
 
-For performance-critical applications, frequent calls to C<PadWalker::peek_my()> and C<caller()> may be too intensive
+For performance-critical applications,
+frequent calls to C<PadWalker::peek_my()> and C<caller()> may be too intensive
 
-=head3 Solutions:
+=head3 Solutions
 
 =over
 
+=item *
 Globally disable all functionality by calling C<Debug::Statements::disable();>
 The PadWalker and caller functions will not be called.  Debug statements will not be printed.
 
-A second technique is to comment out some of your calls to C<d()> within performance-critical loops
+=item *
+OR comment out some of your calls to C<d()> within performance-critical loops
 
-A third technique to completely disable this code is to define you own empty d() subroutines.
+=item *
+OR completely disable this code is to define you own empty d() subroutines.
 
     #use Debug::Statements qw(d d2);
     d{}; d2{};
@@ -1071,5 +1102,10 @@ A third technique to completely disable this code is to define you own empty d()
 
 Chris Koknat 2014 chris.koknat@gmail.com
 
-=cut
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2013-14 by Chris Koknat.
+
+This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
+
+=cut
